@@ -10,7 +10,15 @@ class ReplacyPipelineOrderError(RuntimeError):
 class ESpan(Span):
     @staticmethod
     def create_instance(span: Span):
-        espan = ESpan(span.doc, span.start, span.end, span.label, span.vector, span.vector_norm, span.kb_id)
+        espan = ESpan(
+            span.doc,
+            span.start,
+            span.end,
+            span.label,
+            span.vector,
+            span.vector_norm,
+            span.kb_id,
+        )
         espan.start_character = espan.start_char
         espan.end_character = espan.end_char
         espan.fixed_text = espan.text
@@ -24,22 +32,22 @@ class ESpan(Span):
         return espan
 
     def __getattribute__(self, item):
-        if item == 'start_char' and hasattr(self, 'start_character'):
+        if item == "start_char" and hasattr(self, "start_character"):
             return self.start_character
-        elif item == 'end_char' and hasattr(self, 'end_character'):
+        elif item == "end_char" and hasattr(self, "end_character"):
             return self.end_character
-        elif item == 'text' and hasattr(self, 'fixed_text'):
+        elif item == "text" and hasattr(self, "fixed_text"):
             return self.fixed_text
         else:
             return object.__getattribute__(self, item)
 
     def __setattr__(self, key, value):
-        if key == 'start_char':
+        if key == "start_char":
             self.start_character = value
-            self.fixed_text = self.doc.text[self.start_character:self.end_character]
-        elif key == 'end_char':
+            self.fixed_text = self.doc.text[self.start_character : self.end_character]
+        elif key == "end_char":
             self.end_character = value
-            self.fixed_text = self.doc.text[self.start_character:self.end_character]
+            self.fixed_text = self.doc.text[self.start_character : self.end_character]
         else:
             object.__setattr__(self, key, value)
 
@@ -51,68 +59,67 @@ class IssueBoundary:
     @staticmethod
     def _would_cause_lowercase_first_letter(span: Span) -> bool:
         return (
-                span.start_char == 0
-                and len(span._.suggestions) > 0
-                and span._.suggestions[0] == ""
+            span.start_char == 0
+            and len(span._.suggestions) > 0
+            and span._.suggestions[0] == ""
         )
 
     @staticmethod
     def _would_cause_double_space(span: Span) -> bool:
         return (
-                span.start_char > 0
-                and span.end_char < len(span.doc.text)
-                and len(span._.suggestions) > 0
-                and span.doc.text[span.start_char - 1] == " "
-                and span.doc.text[span.end_char] == " "
-                and span._.suggestions[0] in ["", ","]
+            span.start_char > 0
+            and span.end_char < len(span.doc.text)
+            and len(span._.suggestions) > 0
+            and span.doc.text[span.start_char - 1] == " "
+            and span.doc.text[span.end_char] == " "
+            and span._.suggestions[0] in ["", ","]
         )
 
     @staticmethod
     def _would_cause_space_at_start(span: Span) -> bool:
         return (
-                span.start_char == 0
-                and span.end_char < len(span.doc.text)
-                and span.doc.text[span.end_char] == ' '
-                and len(span._.suggestions) > 0
-                and span._.suggestions[0] == ""
+            span.start_char == 0
+            and span.end_char < len(span.doc.text)
+            and span.doc.text[span.end_char] == " "
+            and len(span._.suggestions) > 0
+            and span._.suggestions[0] == ""
         )
 
     @staticmethod
     def _would_cause_double_comma(span: Span) -> bool:
         return (
-                (
-                        (
-                                span.start_char > 0
-                                and span.doc.text[span.start_char - 1] == ","
-                        )
-                        or
-                        (
-                                span.start_char > 1
-                                and span.doc.text[span.start_char - 1] == " "
-                                and span.doc.text[span.start_char - 2] == ","
-                        )
+            (
+                (span.start_char > 0 and span.doc.text[span.start_char - 1] == ",")
+                or (
+                    span.start_char > 1
+                    and span.doc.text[span.start_char - 1] == " "
+                    and span.doc.text[span.start_char - 2] == ","
                 )
-                and (span.end_char < len(span.doc.text) and span.doc.text[span.end_char] == ",")
-                and len(span._.suggestions) > 0
-                and span._.suggestions[0] == ""
+            )
+            and (
+                span.end_char < len(span.doc.text)
+                and span.doc.text[span.end_char] == ","
+            )
+            and len(span._.suggestions) > 0
+            and span._.suggestions[0] == ""
         )
 
     @staticmethod
     def _would_cause_comma_start(span: Span) -> bool:
         return (
-                span.start_char == 0
-                and span.end_char < len(span.doc.text)
-                and span.doc.text[span.end_char] == ","
-                and len(span._.suggestions) > 0
-                and span._.suggestions[0] == ""
+            span.start_char == 0
+            and span.end_char < len(span.doc.text)
+            and span.doc.text[span.end_char] == ","
+            and len(span._.suggestions) > 0
+            and span._.suggestions[0] == ""
         )
 
     @staticmethod
     def _is_comma_replacement_that_could_be_deletion(span: Span) -> bool:
         return (
-                (span.text[0] == "," or span.text[-1] == ",")
-                and len(span._.suggestions) > 0
-                and span._.suggestions[0] == ","
+            (span.text[0] == "," or span.text[-1] == ",")
+            and len(span._.suggestions) > 0
+            and span._.suggestions[0] == ","
         )
 
     @staticmethod
@@ -142,23 +149,23 @@ class IssueBoundary:
     @staticmethod
     def _would_cause_parenthesis_space(span: Span) -> bool:
         return (
-                span.start_char > 0
-                and span.end_char < len(span.doc.text)
-                and len(span._.suggestions) > 0
-                and span.doc.text[span.start_char - 1] == "("
-                and span.doc.text[span.end_char] == " "
-                and span._.suggestions[0] in [""]
+            span.start_char > 0
+            and span.end_char < len(span.doc.text)
+            and len(span._.suggestions) > 0
+            and span.doc.text[span.start_char - 1] == "("
+            and span.doc.text[span.end_char] == " "
+            and span._.suggestions[0] in [""]
         )
 
     @staticmethod
     def _would_cause_space_parenthesis(span: Span) -> bool:
         return (
-                span.start_char > 0
-                and span.end_char < len(span.doc.text)
-                and len(span._.suggestions) > 0
-                and span.doc.text[span.start_char - 1] == " "
-                and span.doc.text[span.end_char] == ")"
-                and span._.suggestions[0] in [""]
+            span.start_char > 0
+            and span.end_char < len(span.doc.text)
+            and len(span._.suggestions) > 0
+            and span.doc.text[span.start_char - 1] == " "
+            and span.doc.text[span.end_char] == ")"
+            and span._.suggestions[0] in [""]
         )
 
     @staticmethod
@@ -177,10 +184,36 @@ class IssueBoundary:
 
     @staticmethod
     def _drop_comma_when_empty_top(span: Span) -> Span:
-        if len(span._.suggestions) > 0 and span._.suggestions[0] == "" and "," in span._.suggestions:
+        if (
+            len(span._.suggestions) > 0
+            and span._.suggestions[0] == ""
+            and "," in span._.suggestions
+        ):
             span._.suggestions.remove(",")
         return span
 
+    @staticmethod
+    def starts_with_contraction(s: str) -> bool:
+        contractions_list = ["n't", "'ll", "'s", "'d", "'re", "'m"]
+        contractions_list = contractions_list + [
+            c.replace("'", "’") for c in contractions_list
+        ]
+        return any(s.startswith(c) for c in contractions_list)
+
+    @staticmethod
+    def extend_span_with_contraction(spans: List[Span]) -> List[Span]:
+        result = []
+        for span in spans:
+            if len(span.doc) > span.start + 1:
+                next_token = span.doc[span.start + 1]
+                if IssueBoundary.starts_with_contraction(next_token.text):
+                    result.append(span.doc[span.start + 2])
+                else:
+                    result.append(span)
+            else:
+                result.append(span)
+        return result
+
     def __call__(self, spans: List[Span]) -> List[Span]:
         result = []
         for span in spans:
@@ -203,11 +236,12 @@ class IssueBoundary:
 
             if IssueBoundary._would_cause_lowercase_first_letter(span):
                 # casing issue, extending issue forward one word and uppercasing that word
-                doc_text_without_issue = span.doc.text[span.end_char:]
-                first_space_index = doc_text_without_issue.find(' ')
-                replacement = doc_text_without_issue[0:first_space_index]
-                span.end_char += first_space_index
-                span._.suggestions = [replacement[0].upper() + replacement[1:]]
+                doc_text_without_issue = span.doc.text[span.end_char :]
+                first_space_index = doc_text_without_issue.find(" ")
+                if first_space_index > 0:
+                    replacement = doc_text_without_issue[0:first_space_index]
+                    span.end_char += first_space_index
+                    span._.suggestions = [replacement[0].upper() + replacement[1:]]
 
             # order matters, must come after _would_cause_lowercase_first_letter
             if IssueBoundary._is_comma_replacement_that_could_be_deletion(span):
